Documentation
¶
Index ¶
- func ParseDatalink(fsPath string, proc *process.Process) (string, []int64, error)
- type Datalink
- func (d Datalink) GetBytes(proc *process.Process) ([]byte, error)
- func (d Datalink) GetPlainText(proc *process.Process) ([]byte, error)
- func (d Datalink) NewReadCloser(proc *process.Process) (io.ReadCloser, error)
- func (d Datalink) NewWriter(proc *process.Process) (*fileservice.FileServiceWriter, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ParseDatalink ¶
ParseDatalink extracts data from a Datalink string and returns the Mo FS url, []int{offset,size}, fileType and error Mo FS url: The URL that is used by MO FS to access the file offsetSize: The offset and size of the file to be read
Types ¶
type Datalink ¶
func (Datalink) GetPlainText ¶
func (Datalink) NewReadCloser ¶
func (Datalink) NewWriter ¶
func (d Datalink) NewWriter(proc *process.Process) (*fileservice.FileServiceWriter, error)
Click to show internal directories.
Click to hide internal directories.