Documentation
¶
Overview ¶
Package mock_executor is a generated GoMock package.
Index ¶
- type MockSQLExecutor
- type MockSQLExecutorMockRecorder
- type MockTxnExecutor
- func (m *MockTxnExecutor) EXPECT() *MockTxnExecutorMockRecorder
- func (m *MockTxnExecutor) Exec(sql string, options executor.StatementOption) (executor.Result, error)
- func (m *MockTxnExecutor) LockTable(table string) error
- func (m *MockTxnExecutor) Txn() client.TxnOperator
- func (m *MockTxnExecutor) Use(db string)
- type MockTxnExecutorMockRecorder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockSQLExecutor ¶
type MockSQLExecutor struct {
// contains filtered or unexported fields
}
MockSQLExecutor is a mock of SQLExecutor interface.
func NewMockSQLExecutor ¶
func NewMockSQLExecutor(ctrl *gomock.Controller) *MockSQLExecutor
NewMockSQLExecutor creates a new mock instance.
func (*MockSQLExecutor) EXPECT ¶
func (m *MockSQLExecutor) EXPECT() *MockSQLExecutorMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockSQLExecutorMockRecorder ¶
type MockSQLExecutorMockRecorder struct {
// contains filtered or unexported fields
}
MockSQLExecutorMockRecorder is the mock recorder for MockSQLExecutor.
func (*MockSQLExecutorMockRecorder) Exec ¶
func (mr *MockSQLExecutorMockRecorder) Exec(ctx, sql, opts interface{}) *gomock.Call
Exec indicates an expected call of Exec.
func (*MockSQLExecutorMockRecorder) ExecTxn ¶
func (mr *MockSQLExecutorMockRecorder) ExecTxn(ctx, execFunc, opts interface{}) *gomock.Call
ExecTxn indicates an expected call of ExecTxn.
type MockTxnExecutor ¶
type MockTxnExecutor struct {
// contains filtered or unexported fields
}
MockTxnExecutor is a mock of TxnExecutor interface.
func NewMockTxnExecutor ¶
func NewMockTxnExecutor(ctrl *gomock.Controller) *MockTxnExecutor
NewMockTxnExecutor creates a new mock instance.
func (*MockTxnExecutor) EXPECT ¶
func (m *MockTxnExecutor) EXPECT() *MockTxnExecutorMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockTxnExecutor) Exec ¶
func (m *MockTxnExecutor) Exec(sql string, options executor.StatementOption) (executor.Result, error)
Exec mocks base method.
func (*MockTxnExecutor) LockTable ¶
func (m *MockTxnExecutor) LockTable(table string) error
LockTable mocks base method.
func (*MockTxnExecutor) Txn ¶
func (m *MockTxnExecutor) Txn() client.TxnOperator
Txn mocks base method.
type MockTxnExecutorMockRecorder ¶
type MockTxnExecutorMockRecorder struct {
// contains filtered or unexported fields
}
MockTxnExecutorMockRecorder is the mock recorder for MockTxnExecutor.
func (*MockTxnExecutorMockRecorder) Exec ¶
func (mr *MockTxnExecutorMockRecorder) Exec(sql, options interface{}) *gomock.Call
Exec indicates an expected call of Exec.
func (*MockTxnExecutorMockRecorder) LockTable ¶
func (mr *MockTxnExecutorMockRecorder) LockTable(table interface{}) *gomock.Call
LockTable indicates an expected call of LockTable.
func (*MockTxnExecutorMockRecorder) Txn ¶
func (mr *MockTxnExecutorMockRecorder) Txn() *gomock.Call
Txn indicates an expected call of Txn.
func (*MockTxnExecutorMockRecorder) Use ¶
func (mr *MockTxnExecutorMockRecorder) Use(db interface{}) *gomock.Call
Use indicates an expected call of Use.